@@ -321,10 +321,12 @@ class Phar extends RecursiveDirectoryIterator implements RecursiveIterator, Seek
 	 * (PHP &gt;= 5.3.0, PECL phar &gt;= 1.0.0)<br/>
 	 * Returns phar archive meta-data
 	 * @link https://php.net/manual/en/phar.getmetadata.php
+	 * @param array $unserialize_options [optional] if is set to anything other than the default,
+	 * the resulting metadata won't be cached and this won't return the value from the cache
 	 * @return mixed any PHP variable that can be serialized and is stored as meta-data for the Phar archive,
 	 * or <b>NULL</b> if no meta-data is stored.
 	 */
-	public function getMetadata () {}
+	public function getMetadata (array $unserialize_options = []) {}
 
 	/**
 	 * (PHP &gt;= 5.3.0, PECL phar &gt;= 1.0.0)<br/>
@@ -1090,10 +1092,12 @@ class PharFileInfo extends SplFileInfo  {
 	 * (PHP &gt;= 5.3.0, PECL phar &gt;= 1.0.0)<br/>
 	 * Returns file-specific meta-data saved with a file
 	 * @link https://php.net/manual/en/pharfileinfo.getmetadata.php
+	 * @param array $unserialize_options [optional] if is set to anything other than the default,
+	 * the resulting metadata won't be cached and this won't return the value from the cache
 	 * @return mixed any PHP variable that can be serialized and is stored as meta-data for the file,
 	 * or <b>NULL</b> if no meta-data is stored.
 	 */
-	public function getMetadata () {}
+	public function getMetadata (array $unserialize_options = []) {}
 
 	/**
 	 * (PHP &gt;= 5.3.0, PECL phar &gt;= 1.0.0)<br/>
