@@ -9,6 +9,7 @@
  * Resource holding the key.
  * </p>
  * @return void
+ * @deprecated 8.0
  */
 function openssl_pkey_free($key) { }
 
@@ -30,7 +31,7 @@ function openssl_pkey_new(array $configargs = null) { }
  * Gets an exportable representation of a key into a string
  * @link https://php.net/manual/en/function.openssl-pkey-export.php
  * @param mixed $key
- * @param string $out
+ * @param string &$out
  * @param string $passphrase [optional] <p>
  * The key is optionally protected by <i>passphrase</i>.
  * </p>
@@ -129,6 +130,7 @@ function openssl_pkey_get_details($key) { }
  * @link https://php.net/manual/en/function.openssl-free-key.php
  * @param resource $key_identifier
  * @return void
+ * @deprecated 8.0
  */
 function openssl_free_key($key_identifier) { }
 
@@ -174,14 +176,14 @@ function openssl_get_publickey($certificate) { }
 /**
  * Generate a new signed public key and challenge
  * @link https://php.net/manual/en/function.openssl-spki-new.php
- * @param resource $privkey <p>
+ * @param resource &$privkey <p>
  * <b>privkey</b> should be set to a private key that was
  * previously generated by {@link https://php.net/en/manual/function.openssl-pkey-new.php openssl_pkey_new()} (or
  * otherwise obtained from the other openssl_pkey family of functions).
  * The corresponding public portion of the key will be used to sign the
  * CSR.
  * </p>
- * @param string $challenge <p>The challenge associated to associate with the SPKAC</p>
+ * @param string &$challenge <p>The challenge associated to associate with the SPKAC</p>
  * @param int $algorithm <p>The digest algorithm. See openssl_get_md_method().</p>
  * @return string|null Returns a signed public key and challenge string or NULL on failure.
  * @since 5.6
@@ -192,7 +194,7 @@ function openssl_spki_new(&$privkey, &$challenge, $algorithm = 0) {}
 /**
  * Verifies a signed public key and challenge
  * @link https://php.net/manual/en/function.openssl-spki-verify.php
- * @param string $spkac <p>Expects a valid signed public key and challenge</p>
+ * @param string &$spkac <p>Expects a valid signed public key and challenge</p>
  * @return bool Returns a boolean on success or failure.
  * @since 5.6
  */
@@ -201,7 +203,7 @@ function openssl_spki_verify(&$spkac) {}
 /**
  * Exports the challenge associated with a signed public key and challenge
  * @link https://php.net/manual/en/function.openssl-spki-export-challenge.php
- * @param string $spkac <p>Expects a valid signed public key and challenge</p>
+ * @param string &$spkac <p>Expects a valid signed public key and challenge</p>
  * @return string|null Returns the associated challenge string or NULL on failure.
  * @since 5.6
  */
@@ -210,7 +212,7 @@ function openssl_spki_export_challenge (&$spkac ) {}
 /**
  * Exports a valid PEM formatted public key signed public key and challenge
  * @link https://php.net/manual/en/function.openssl-spki-export.php
- * @param string $spkac <p>Expects a valid signed public key and challenge</p>
+ * @param string &$spkac <p>Expects a valid signed public key and challenge</p>
  * @return string|null Returns the associated PEM formatted public key or NULL on failure.
  * @since 5.6
  */
@@ -237,6 +239,7 @@ function openssl_x509_fingerprint($x509, $type, $binary) {}
  * @link https://php.net/manual/en/function.openssl-x509-free.php
  * @param resource $x509cert
  * @return void
+ * @deprecated 8.0
  */
 function openssl_x509_free($x509cert) { }
 
@@ -335,7 +338,7 @@ function openssl_x509_check_private_key($cert, $key) { }
  * Exports a certificate as a string
  * @link https://php.net/manual/en/function.openssl-x509-export.php
  * @param mixed $x509
- * @param string $output <p>
+ * @param string &$output <p>
  * On success, this will hold the PEM.
  * </p>
  * @param bool $notext [optional] &note.openssl.param-notext;
@@ -364,7 +367,7 @@ function openssl_x509_verify($cert, $key){}
  * Exports a PKCS#12 Compatible Certificate Store File to variable.
  * @link https://php.net/manual/en/function.openssl-pkcs12-export.php
  * @param mixed $x509
- * @param string $out <p>
+ * @param string &$out <p>
  * On success, this will hold the PKCS#12.
  * </p>
  * @param mixed $priv_key <p>
@@ -402,7 +405,7 @@ function openssl_pkcs12_export_to_file($x509, $filename, $priv_key, $pass, array
  * Parse a PKCS#12 Certificate Store into an array
  * @link https://php.net/manual/en/function.openssl-pkcs12-read.php
  * @param string $pkcs12
- * @param array $certs <p>
+ * @param array &$certs <p>
  * On success, this will hold the Certificate Store Data.
  * </p>
  * @param string $pass <p>
@@ -419,7 +422,7 @@ function openssl_pkcs12_read($pkcs12, array &$certs, $pass) { }
  * @param array $dn <p>
  * The Distinguished Name to be used in the certificate.
  * </p>
- * @param resource $privkey <p>
+ * @param resource &$privkey <p>
  * <i>privkey</i> should be set to a private key that was
  * previously generated by <b>openssl_pkey_new</b> (or
  * otherwise obtained from the other openssl_pkey family of functions).
@@ -512,7 +515,7 @@ function openssl_csr_new(array $dn, &$privkey, array $configargs = null, array $
  * Exports a CSR as a string
  * @link https://php.net/manual/en/function.openssl-csr-export.php
  * @param resource $csr
- * @param string $out
+ * @param string &$out
  * @param bool $notext [optional] &note.openssl.param-notext;
  * @return bool true on success or false on failure.
  */
@@ -670,7 +673,7 @@ function openssl_cipher_iv_length($method) { }
  * Generate signature
  * @link https://php.net/manual/en/function.openssl-sign.php
  * @param string $data
- * @param string $signature <p>
+ * @param string &$signature <p>
  * If the call was successful the signature is returned in
  * <i>signature</i>.
  * </p>
@@ -700,11 +703,11 @@ function openssl_verify($data, $signature, $pub_key_id, $signature_alg = OPENSSL
  * Seal (encrypt) data
  * @link https://php.net/manual/en/function.openssl-seal.php
  * @param string $data
- * @param string $sealed_data
- * @param array $env_keys
+ * @param string &$sealed_data
+ * @param array &$env_keys
  * @param array $pub_key_ids
  * @param string $method [optional]
- * @param string $iv [optional]
+ * @param string &$iv [optional]
  * @return int|false the length of the sealed data on success, or false on error.
  * If successful the sealed data is returned in
  * <i>sealed_data</i>, and the envelope keys in
@@ -716,7 +719,7 @@ function openssl_seal($data, &$sealed_data, array &$env_keys, array $pub_key_ids
  * Open sealed data
  * @link https://php.net/manual/en/function.openssl-open.php
  * @param string $sealed_data
- * @param string $open_data <p>
+ * @param string &$open_data <p>
  * If the call is successful the opened data is returned in this
  * parameter.
  * </p>
@@ -851,7 +854,7 @@ function openssl_pkcs7_encrypt($infile, $outfile, $recipcerts, array $headers, $
  * Encrypts data with private key
  * @link https://php.net/manual/en/function.openssl-private-encrypt.php
  * @param string $data
- * @param string $crypted
+ * @param string &$crypted
  * @param mixed $key
  * @param int $padding [optional] <p>
  * <i>padding</i> can be one of
@@ -866,7 +869,7 @@ function openssl_private_encrypt($data, &$crypted, $key, $padding = OPENSSL_PKCS
  * Decrypts data with private key
  * @link https://php.net/manual/en/function.openssl-private-decrypt.php
  * @param string $data
- * @param string $decrypted
+ * @param string &$decrypted
  * @param mixed $key <p>
  * <i>key</i> must be the private key corresponding that
  * was used to encrypt the data.
@@ -886,7 +889,7 @@ function openssl_private_decrypt($data, &$decrypted, $key, $padding = OPENSSL_PK
  * Encrypts data with public key
  * @link https://php.net/manual/en/function.openssl-public-encrypt.php
  * @param string $data
- * @param string $crypted <p>
+ * @param string &$crypted <p>
  * This will hold the result of the encryption.
  * </p>
  * @param mixed $key <p>
@@ -907,7 +910,7 @@ function openssl_public_encrypt($data, &$crypted, $key, $padding = OPENSSL_PKCS1
  * Decrypts data with public key
  * @link https://php.net/manual/en/function.openssl-public-decrypt.php
  * @param string $data
- * @param string $decrypted
+ * @param string &$decrypted
  * @param mixed $key <p>
  * <i>key</i> must be the public key corresponding that
  * was used to encrypt the data.
@@ -974,12 +977,12 @@ function openssl_pkey_derive($peer_pub_key, $priv_key, $keylen) {}
  * The length of the desired string of bytes. Must be a positive integer. PHP will
  * try to cast this parameter to a non-null integer to use it.
  * </p>
- * @param bool $crypto_strong [optional]<p>
+ * @param bool &$crypto_strong [optional]<p>
  * If passed into the function, this will hold a boolean value that determines
  * if the algorithm used was "cryptographically strong", e.g., safe for usage with GPG,
  * passwords, etc. true if it did, otherwise false
  * </p>
- * @return string|false the generated &string; of bytes on success, or false on failure.
+ * @return string|false the generated string of bytes on success, or false on failure.
  */
 function openssl_random_pseudo_bytes($length, &$crypto_strong = null) { }
 
@@ -1003,7 +1006,7 @@ function openssl_get_curve_names() {}
 
 /**
  * @param string $P7B
- * @param array $certs
+ * @param array &$certs
  * @return bool
  * @since 7.2
  */
@@ -1235,3 +1238,18 @@ define('OPENSSL_DEFAULT_STREAM_CIPHERS', "ECDHE-RSA-AES128-GCM-SHA256:ECDHE-ECDS
 "ECDHE-RSA-AES256-SHA:ECDHE-ECDSA-AES256-SHA:DHE-RSA-AES128-SHA256:DHE-RSA-AES128-SHA:" .
 "DHE-DSS-AES128-SHA256:DHE-RSA-AES256-SHA256:DHE-DSS-AES256-SHA:DHE-RSA-AES256-SHA:AES128-GCM-SHA256:" .
 "AES256-GCM-SHA384:AES128:AES256:HIGH:!SSLv2:!aNULL:!eNULL:!EXPORT:!DES:!MD5:!RC4:!ADH");
+
+/**
+ * @since 8.0
+ */
+final class OpenSSLCertificate{}
+
+/**
+ * @since 8.0
+ */
+final class OpenSSLCertificateSigningRequest{}
+
+/**
+ * @since 8.0
+ */
+final class OpenSSLAsymmetricKey{}
