@@ -297,7 +297,7 @@ class SoapClient  {
 	 * @param mixed $input_headers [optional] <p>
 	 * An array of headers to be sent along with the SOAP request.
 	 * </p>
-	 * @param array $output_headers [optional] <p>
+	 * @param array &$output_headers [optional] <p>
 	 * If supplied, this array will be filled with the headers from the SOAP response.
 	 * </p>
 	 * @return mixed SOAP functions may return one, or multiple values. If only one value is returned
@@ -543,11 +543,11 @@ class SoapServer  {
 	 * @param string $class_name <p>
 	 * The name of the exported class.
 	 * </p>
-	 * @param mixed $_ [optional] These optional parameters will be passed to the default class constructor during object creation.
+	 * @param mixed ...$_ [optional] These optional parameters will be passed to the default class constructor during object creation.
 	 * @return void No value is returned.
 	 * @since 5.0.1
 	 */
-	public function setClass ($class_name, $_ = null) {}
+	public function setClass ($class_name, ...$_) {}
 
 	/**
 	 * Sets the object which will be used to handle SOAP requests
