@@ -77,7 +77,7 @@ function abs ($number) {}
  * @return float|false value rounded up to the next highest
  * integer.
  * The return value of ceil is still of type
- * float as the value range of float is 
+ * float as the value range of float is
  * usually bigger than that of integer.
  */
 function ceil ($value) {}
@@ -90,7 +90,7 @@ function ceil ($value) {}
  * </p>
  * @return float|false value rounded to the next lowest integer.
  * The return value of floor is still of type
- * float because the value range of float is 
+ * float because the value range of float is
  * usually bigger than that of integer.
  */
 function floor ($value) {}
@@ -112,7 +112,7 @@ function floor ($value) {}
  * PHP_ROUND_HALF_EVEN, or
  * PHP_ROUND_HALF_ODD.
  * </p>
- * @return float|false The rounded value
+ * @return float The rounded value
  */
 function round ($val, $precision = 0, $mode = PHP_ROUND_HALF_UP) {}
 
@@ -130,7 +130,7 @@ function sin ($arg) {}
  * Cosine
  * @link https://php.net/manual/en/function.cos.php
  * @param float $arg <p>
- * An angle in radians 
+ * An angle in radians
  * </p>
  * @return float The cosine of arg
  */
@@ -140,7 +140,7 @@ function cos ($arg) {}
  * Tangent
  * @link https://php.net/manual/en/function.tan.php
  * @param float $arg <p>
- * The argument to process in radians 
+ * The argument to process in radians
  * </p>
  * @return float The tangent of arg
  */
@@ -195,7 +195,7 @@ function atanh ($arg) {}
  * @param float $x <p>
  * Divisor parameter
  * </p>
- * @return float The arc tangent of y/x 
+ * @return float The arc tangent of y/x
  * in radians.
  */
 function atan2 ($y, $x) {}
@@ -305,8 +305,8 @@ function is_nan ($val) {}
 /**
  * Integer division
  * @link https://php.net/manual/en/function.intdiv.php
- * @param $dividend <p>Number to be divided.</p>
- * @param $divisor <p>Number which divides the <b><i>dividend</i></b></p>
+ * @param int $dividend <p>Number to be divided.</p>
+ * @param int $divisor <p>Number which divides the <b><i>dividend</i></b></p>
  * @return int <p>
  * If divisor is 0, a {@link DivisionByZeroError} exception is thrown.
  * If the <b><i>dividend</i></b> is <b>PHP_INT_MIN</b> and the <b><i>divisor</i></b> is -1,
@@ -359,10 +359,10 @@ function exp ($arg) {}
  * The value to calculate the logarithm for
  * </p>
  * @param float $base [optional] <p>
- * The optional logarithmic base to use 
+ * The optional logarithmic base to use
  * (defaults to 'e' and so to the natural logarithm).
  * </p>
- * @return float The logarithm of arg to 
+ * @return float The logarithm of arg to
  * base, if given, or the
  * natural logarithm.
  */
@@ -406,7 +406,7 @@ function hypot ($x, $y) {}
  * Converts the number in degrees to the radian equivalent
  * @link https://php.net/manual/en/function.deg2rad.php
  * @param float $number <p>
- * Angular value in degrees 
+ * Angular value in degrees
  * </p>
  * @return float The radian equivalent of number
  */
@@ -631,11 +631,19 @@ function number_format ($number , $decimals = 0 , $dec_point = '.' , $thousands_
  * @param float $y <p>
  * The divisor
  * </p>
- * @return float The floating point remainder of 
+ * @return float The floating point remainder of
  * x/y
  */
 function fmod ($x, $y) {}
 
+/**
+ * Performs a floating-point division under
+ * IEEE 754 semantics. Division by zero is considered well-defined and
+ * will return one of Inf, -Inf or NaN.
+ * @since 8.0
+ */
+function fdiv(float $dividend, float $divisor): float {}
+
 /**
  * Converts a packed internet address to a human readable representation
  * @link https://php.net/manual/en/function.inet-ntop.php
@@ -718,7 +726,7 @@ function putenv ($setting) {}
  * For example, an longopts element "opt" recognizes an
  * option --opt.
  * Prior to PHP5.3.0 this parameter was only available on few systems
- * @param int $optind If the optind parameter is present, then the index where argument parsing stopped will be written to this variable.
+ * @param int &$optind If the optind parameter is present, then the index where argument parsing stopped will be written to this variable.
  * @return string[]|false[]|false This function will return an array of option / argument pairs or false on
  * failure.
  */
@@ -837,6 +845,7 @@ function quoted_printable_encode ($str) {}
  * </p>
  * @return string the converted string.
  * @deprecated 7.4
+ * @removed 8.0
  */
 function convert_cyr_string ($str, $from, $to) {}
 
@@ -854,7 +863,7 @@ function get_current_user () {}
  * The maximum execution time, in seconds. If set to zero, no time limit
  * is imposed.
  * </p>
- * @return bool Returns TRUE on success, or FALSE on failure. 
+ * @return bool Returns TRUE on success, or FALSE on failure.
  */
 function set_time_limit ($seconds) {}
 
@@ -873,7 +882,7 @@ function get_cfg_var ($option) {}
  * &Alias; <function>set_magic_quotes_runtime</function>
  * @link https://php.net/manual/en/function.magic-quotes-runtime.php
  * @deprecated 5.3
- * @param $new_setting
+ * @param bool $new_setting
  * @removed 7.0
  */
 function magic_quotes_runtime ($new_setting) {}
@@ -896,6 +905,7 @@ function set_magic_quotes_runtime ($new_setting) {}
  * @link https://php.net/manual/en/function.get-magic-quotes-gpc.php
  * @return int 0 if magic quotes gpc are off, 1 otherwise.
  * @deprecated 7.4
+ * @removed 8.0
  */
 function get_magic_quotes_gpc () {}
 
@@ -912,7 +922,7 @@ function get_magic_quotes_runtime () {}
  * @link https://php.net/manual/en/function.import-request-variables.php
  * @param string $types <p>
  * Using the types parameter, you can specify
- * which request variables to import. You can use 'G', 'P' and 'C' 
+ * which request variables to import. You can use 'G', 'P' and 'C'
  * characters respectively for GET, POST and Cookie. These characters are
  * not case sensitive, so you can also use any combination of 'g', 'p'
  * and 'c'. POST includes the POST uploaded file information.
@@ -950,7 +960,7 @@ function import_request_variables ($types, $prefix = null) {}
  * The error message that should be logged.
  * </p>
  * @param int $message_type [optional] <p>
- * Says where the error should go. The possible message types are as 
+ * Says where the error should go. The possible message types are as
  * follows:
  * </p>
  * <p>
@@ -984,7 +994,7 @@ function import_request_variables ($types, $prefix = null) {}
  * <td>3</td>
  * <td>
  * message is appended to the file
- * destination. A newline is not automatically 
+ * destination. A newline is not automatically
  * added to the end of the message string.
  * </td>
  * </tr>
@@ -998,13 +1008,13 @@ function import_request_variables ($types, $prefix = null) {}
  * </table>
  * </p>
  * @param string $destination [optional] <p>
- * The destination. Its meaning depends on the 
+ * The destination. Its meaning depends on the
  * message_type parameter as described above.
  * </p>
  * @param string $extra_headers [optional] <p>
  * The extra headers. It's used when the message_type
  * parameter is set to 1.
- * This message type uses the same internal function as 
+ * This message type uses the same internal function as
  * mail does.
  * </p>
  * @return bool true on success or false on failure.
