@@ -3,8 +3,8 @@
 /**
  * Get the last occurred error
  * @link https://php.net/manual/en/function.error-get-last.php
- * @return array an associative array describing the last error with keys "type",
- * "message", "file" and "line". Returns &null; if there hasn't been an error
+ * @return array|null an associative array describing the last error with keys "type",
+ * "message", "file" and "line". Returns null if there hasn't been an error
  * yet.
  */
 function error_get_last () {}
@@ -19,7 +19,7 @@ function error_get_last () {}
  * Additionally class methods of an object instance may be called by passing
  * array($objectinstance, $methodname) to this parameter.
  * </p>
- * @param mixed $parameter [optional] <p>
+ * @param mixed ...$parameter [optional] <p>
  * Zero or more parameters to be passed to the function.
  * </p>
  * <p>
@@ -28,7 +28,7 @@ function error_get_last () {}
  * call_user_func example and references
  * &example.outputs;
  * </p>
- * @return mixed the function result, or false on error.
+ * @return mixed|false the function result, or false on error.
  */
 function call_user_func ($function, ...$parameter) {}
 
@@ -41,7 +41,7 @@ function call_user_func ($function, ...$parameter) {}
  * @param array $param_arr <p>
  * The parameters to be passed to the function, as an indexed array.
  * </p>
- * @return mixed the function result, or false on error.
+ * @return mixed|false the function result, or false on error.
  */
 function call_user_func_array ($function, array $param_arr) {}
 
@@ -50,22 +50,21 @@ function call_user_func_array ($function, array $param_arr) {}
  * @link https://php.net/manual/en/function.call-user-method.php
  * @deprecated 5.3 use call_user_func() instead
  * @param string $method_name
- * @param object $obj 
- * @param mixed $parameter [optional] 
- * @param mixed $_ [optional] 
+ * @param object &$obj
+ * @param mixed ...$parameter [optional]
  * @return mixed
  * @removed 7.0
  */
-function call_user_method ($method_name, &$obj, $parameter = null, $_ = null) {}
+function call_user_method ($method_name, &$obj, ...$parameter) {}
 
 /**
  * Call a user method given with an array of parameters
  * @link https://php.net/manual/en/function.call-user-method-array.php
  * @deprecated 5.3 use call_user_func_array() instead
  * @param string $method_name
- * @param object $obj 
- * @param array $params 
- * @return mixed 
+ * @param object &$obj
+ * @param array $params
+ * @return mixed
  * @removed 7.0
  */
 function call_user_method_array ($method_name, &$obj, array $params) {}
@@ -78,26 +77,25 @@ function call_user_method_array ($method_name, &$obj, array $params) {}
  * with the name of the class, and the method, or a string, with a function
  * name.
  * </p>
- * @param mixed $parameter [optional] <p>
+ * @param mixed ...$parameters [optional] <p>
  * Zero or more parameters to be passed to the function.
  * </p>
- * @param mixed $_ [optional] 
- * @return mixed the function result, or false on error.
+ * @return mixed|false the function result, or false on error.
  */
-function forward_static_call ($function, $parameter = null, $_ = null) {}
+function forward_static_call ($function, ...$parameters) {}
 
 /**
  * Call a static method and pass the arguments as array
  * @link https://php.net/manual/en/function.forward-static-call-array.php
- * @param callback $function <p>
- * The function or method to be called. This parameter may be an &array;,
- * with the name of the class, and the method, or a &string;, with a function
+ * @param callback|array|string $function <p>
+ * The function or method to be called. This parameter may be an array,
+ * with the name of the class, and the method, or a string, with a function
  * name.
  * </p>
- * @param array $parameters [optional] 
- * @return mixed the function result, or false on error.
+ * @param array $parameters
+ * @return mixed|false the function result, or false on error.
  */
-function forward_static_call_array ($function, array $parameters = null) {}
+function forward_static_call_array ($function, array $parameters) {}
 
 /**
  * Generates a storable representation of a value
@@ -106,15 +104,15 @@ function forward_static_call_array ($function, array $parameters = null) {}
  * The value to be serialized. serialize
  * handles all types, except the resource-type.
  * You can even serialize arrays that contain
- * references to itself. Circular references inside the array/object you 
- * are serializing will also be stored. Any other 
+ * references to itself. Circular references inside the array/object you
+ * are serializing will also be stored. Any other
  * reference will be lost.
  * </p>
  * <p>
  * When serializing objects, PHP will attempt to call the member function
- * __sleep prior to serialization. 
- * This is to allow the object to do any last minute clean-up, etc. prior 
- * to being serialized. Likewise, when the object is restored using 
+ * __sleep prior to serialization.
+ * This is to allow the object to do any last minute clean-up, etc. prior
+ * to being serialized. Likewise, when the object is restored using
  * unserialize the __wakeup member function is called.
  * </p>
  * <p>
@@ -122,7 +120,7 @@ function forward_static_call_array ($function, array $parameters = null) {}
  * name; protected members have a '*' prepended to the member name.
  * These prepended values have null bytes on either side.
  * </p>
- * @return string a string containing a byte-stream representation of 
+ * @return string a string containing a byte-stream representation of
  * value that can be stored anywhere.
  */
 function serialize ($value) {}
@@ -134,7 +132,7 @@ function serialize ($value) {}
  * The serialized string.
  * </p>
  * <p>
- * If the variable being unserialized is an object, after successfully 
+ * If the variable being unserialized is an object, after successfully
  * reconstructing the object PHP will automatically attempt to call the
  * __wakeup member function (if it exists).
  * </p>
@@ -144,15 +142,16 @@ function serialize ($value) {}
  * It's possible to set a callback-function which will be called,
  * if an undefined class should be instantiated during unserializing.
  * (to prevent getting an incomplete object "__PHP_Incomplete_Class".)
- * Use your &php.ini;, ini_set or &htaccess; 
+ * Use your &php.ini;, ini_set or &htaccess;
  * to define 'unserialize_callback_func'. Everytime an undefined class
  * should be instantiated, it'll be called. To disable this feature just
  * empty this setting.
  * </p>
- * @param mixed $options [optional]
+ * @param array $options [optional]
  * <p>Any options to be provided to unserialize(), as an associative array.</p>
  * <p>
- * Either an array of class names which should be accepted, FALSE to
+ * The 'allowed_classes' option key may be set to a value that is
+ * either an array of class names which should be accepted, FALSE to
  * accept no classes, or TRUE to accept all classes. If this option is defined
  * and unserialize() encounters an object of a class that isn't to be accepted,
  * then the object will be instantiated as __PHP_Incomplete_Class instead.
@@ -175,10 +174,10 @@ function unserialize (string $str, array $options = []) {}
  * @param mixed $expression <p>
  * The variable you want to export.
  * </p>
- * @param mixed $_ [optional]
- * @return void 
+ * @param mixed ...$_ [optional]
+ * @return void
  */
-function var_dump ($expression, $_ = null) {}
+function var_dump ($expression, ...$_) {}
 
 /**
  * Outputs or returns a parsable string representation of a variable
@@ -193,19 +192,20 @@ function var_dump ($expression, $_ = null) {}
  * &note.uses-ob;
  * @return string|null the variable representation when the return
  * parameter is used and evaluates to true. Otherwise, this function will
- * return &null;.
+ * return null.
  */
 function var_export ($expression, $return = null) {}
 
 /**
  * Dumps a string representation of an internal zend value to output
  * @link https://php.net/manual/en/function.debug-zval-dump.php
- * @param mixed $variable <p>
- * The variable being evaluated.
+ * @param mixed $value The variable being evaluated.
+ * @param mixed ...$values <p>
+ * The other variable being evaluated.
  * </p>
- * @return void 
+ * @return void
  */
-function debug_zval_dump ($variable) {}
+function debug_zval_dump ($value, ...$values) {}
 
 /**
  * Prints human-readable information about a variable
@@ -214,7 +214,7 @@ function debug_zval_dump ($variable) {}
  * The expression to be printed.
  * </p>
  * @param bool $return [optional] <p>
- * If you would like to capture the output of print_r, 
+ * If you would like to capture the output of print_r,
  * use the return parameter. If this parameter is set
  * to true, print_r will return its output, instead of
  * printing it (which it does by default).
@@ -236,7 +236,7 @@ function print_r ($expression, $return = null) {}
  * </p>
  * @return int the memory amount in bytes.
  */
-function memory_get_usage ($real_usage = null) {}
+function memory_get_usage ($real_usage = false) {}
 
 /**
  * Returns the peak of memory allocated by PHP
@@ -248,7 +248,7 @@ function memory_get_usage ($real_usage = null) {}
  * </p>
  * @return int the memory peak in bytes.
  */
-function memory_get_peak_usage ($real_usage = null) {}
+function memory_get_peak_usage ($real_usage = false) {}
 
 /**
  * Register a function for execution on shutdown
@@ -257,7 +257,7 @@ function memory_get_peak_usage ($real_usage = null) {}
  * The shutdown function to register.
  * </p>
  * <p>
- * The shutdown functions are called as the part of the request so that 
+ * The shutdown functions are called as the part of the request so that
  * it's possible to send the output from them. There is currently no way
  * to process the data with output buffering functions in the shutdown
  * function.
@@ -267,14 +267,13 @@ function memory_get_peak_usage ($real_usage = null) {}
  * thus, for example, its output will not be compressed if zlib.output_compression is
  * enabled.
  * </p>
- * @param mixed $parameter [optional] <p>
+ * @param mixed ...$parameters [optional] <p>
  * It is possible to pass parameters to the shutdown function by passing
  * additional parameters.
  * </p>
- * @param mixed $_ [optional] 
- * @return void 
+ * @return void
  */
-function register_shutdown_function ($function, $parameter = null, $_ = null) {}
+function register_shutdown_function ($function, ...$parameters) {}
 
 /**
  * Register a function for execution on each tick
@@ -283,12 +282,11 @@ function register_shutdown_function ($function, $parameter = null, $_ = null) {}
  * The function name as a string, or an array consisting of an object and
  * a method.
  * </p>
- * @param mixed $arg [optional] <p>
+ * @param mixed ...$parameters [optional] <p>
  * </p>
- * @param mixed $_ [optional] 
  * @return bool true on success or false on failure.
  */
-function register_tick_function ($function, $arg = null, $_ = null) {}
+function register_tick_function ($function, ...$parameters) {}
 
 /**
  * De-register a function for execution on each tick
@@ -297,7 +295,7 @@ function register_tick_function ($function, $arg = null, $_ = null) {}
  * The function name as a string, or an array consisting of an object and
  * a method.
  * </p>
- * @return void 
+ * @return void
  */
 function unregister_tick_function ($function) {}
 
@@ -320,8 +318,9 @@ function highlight_file ($filename, $return = false) {}
 /**
  * &Alias; <function>highlight_file</function>
  * @link https://php.net/manual/en/function.show-source.php
- * @param $file_name
- * @param $return [optional]
+ * @param string $file_name
+ * @param bool $return [optional]
+ * @return string|bool
  */
 function show_source ($file_name, $return = false) {}
 
@@ -349,7 +348,7 @@ function highlight_string ($str, $return = false) {}
  * @return int[]|int|float Returns an array of integers in the form [seconds, nanoseconds], if the parameter get_as_number is false.
  * Otherwise the nanoseconds are returned as integer (64bit platforms) or float (32bit platforms).
  */
-function hrtime($get_as_number = FALSE) {}
+function hrtime($get_as_number = false) {}
 
 /**
  * Return source with stripped comments and whitespace
@@ -437,8 +436,9 @@ function ini_set ($varname, $newvalue) {}
  * &Alias; <function>ini_set</function>
  * @link https://php.net/manual/en/function.ini-alter.php
  * @link https://php.net/manual/en/ini.list.php
- * @param $varname
- * @param $newvalue
+ * @param string $varname
+ * @param string $newvalue
+ * @return string|false
  */
 function ini_alter ($varname, $newvalue) {}
 
@@ -449,7 +449,7 @@ function ini_alter ($varname, $newvalue) {}
  * @param string $varname <p>
  * The configuration option name.
  * </p>
- * @return void 
+ * @return void
  */
 function ini_restore ($varname) {}
 
@@ -474,8 +474,9 @@ function set_include_path ($new_include_path) {}
 /**
  * Restores the value of the include_path configuration option
  * @link https://php.net/manual/en/function.restore-include-path.php
- * @return void 
+ * @return void
  * @deprecated 7.4
+ * @removed 8.0
  */
 function restore_include_path () {}
 
@@ -582,13 +583,13 @@ function setcookie($name, $value = '', array $options = []) {}
 /**
  * Send a cookie without urlencoding the cookie value
  * @link https://php.net/manual/en/function.setrawcookie.php
- * @param string $name 
- * @param string $value [optional] 
- * @param int $expire [optional] 
- * @param string $path [optional] 
- * @param string $domain [optional] 
- * @param bool $secure [optional] 
- * @param bool $httponly [optional] 
+ * @param string $name
+ * @param string $value [optional]
+ * @param int $expire [optional]
+ * @param string $path [optional]
+ * @param string $domain [optional]
+ * @param bool $secure [optional]
+ * @param bool $httponly [optional]
  * @return bool true on success or false on failure.
  */
 function setrawcookie ($name, $value = '', $expire = 0, $path = "", $domain = "", $secure = false, $httponly = false) {}
@@ -647,7 +648,7 @@ function setrawcookie ($name, $value = '', array $options = []) {}
  * @param int $http_response_code [optional] <p>
  * Forces the HTTP response code to the specified value.
  * </p>
- * @return void 
+ * @return void
  */
 function header ($string, $replace = true, $http_response_code = null) {}
 
@@ -658,21 +659,21 @@ function header ($string, $replace = true, $http_response_code = null) {}
  * The header name to be removed.
  * </p>
  * This parameter is case-insensitive.
- * @return void 
+ * @return void
  */
 function header_remove ($name = null) {}
 
 /**
  * Checks if or where headers have been sent
  * @link https://php.net/manual/en/function.headers-sent.php
- * @param string $file [optional] <p>
+ * @param string &$file [optional] <p>
  * If the optional file and
- * line parameters are set, 
+ * line parameters are set,
  * headers_sent will put the PHP source file name
  * and line number where output started in the file
  * and line variables.
  * </p>
- * @param int $line [optional] <p>
+ * @param int &$line [optional] <p>
  * The line number where the output started.
  * </p>
  * @return bool headers_sent will return false if no HTTP headers
@@ -687,6 +688,21 @@ function headers_sent (&$file = null, &$line = null) {}
  */
 function headers_list () {}
 
+/**
+ * Fetches all HTTP request headers from the current request
+ * @link https://php.net/manual/en/function.apache-request-headers.php
+ * @return array|false An associative array of all the HTTP headers in the current request, or <b>FALSE</b on failure.
+ */
+function apache_request_headers () {}
+
+/**
+ * Fetches all HTTP headers from the current request.
+ * This function is an alias for apache_request_headers(). Please read the apache_request_headers() documentation for more information on how this function works.
+ * @link https://php.net/manual/en/function.getallheaders.php
+ * @return array|false An associative array of all the HTTP headers in the current request, or <b>FALSE</b> on failure.
+ */
+function getallheaders () {}
+
 /**
  * Check whether client disconnected
  * @link https://php.net/manual/en/function.connection-aborted.php
@@ -725,11 +741,11 @@ function ignore_user_abort ($value = null) {}
  * By setting the process_sections
  * parameter to true, you get a multidimensional array, with
  * the section names and settings included. The default
- * for process_sections is false 
+ * for process_sections is false
  * </p>
  * @param int $scanner_mode [optional] <p>
- * Can either be INI_SCANNER_NORMAL (default) or 
- * INI_SCANNER_RAW. If INI_SCANNER_RAW 
+ * Can either be INI_SCANNER_NORMAL (default) or
+ * INI_SCANNER_RAW. If INI_SCANNER_RAW
  * is supplied, then option values will not be parsed.
  * </p>
  * <p>
@@ -755,11 +771,11 @@ function parse_ini_file ($filename, $process_sections = false, $scanner_mode = I
  * By setting the process_sections
  * parameter to true, you get a multidimensional array, with
  * the section names and settings included. The default
- * for process_sections is false 
+ * for process_sections is false
  * </p>
  * @param int $scanner_mode [optional] <p>
- * Can either be INI_SCANNER_NORMAL (default) or 
- * INI_SCANNER_RAW. If INI_SCANNER_RAW 
+ * Can either be INI_SCANNER_NORMAL (default) or
+ * INI_SCANNER_RAW. If INI_SCANNER_RAW
  * is supplied, then option values will not be parsed.
  * </p>
  * @return array|false The settings are returned as an associative array on success,
@@ -800,6 +816,7 @@ function is_uploaded_file ($filename) {}
 function move_uploaded_file ($filename, $destination) {}
 
 /**
+ * @return array|false
  * @since 7.3
  */
 function net_get_interfaces() {}
@@ -833,7 +850,7 @@ function gethostbyname ($hostname) {}
  * @param string $hostname <p>
  * The host name.
  * </p>
- * @return array an array of IPv4 addresses or false if
+ * @return array|false an array of IPv4 addresses or false if
  * hostname could not be resolved.
  */
 function gethostbynamel ($hostname) {}
@@ -849,11 +866,11 @@ function gethostname () {}
 /**
  * &Alias; <function>checkdnsrr</function>
  * @link https://php.net/manual/en/function.dns-check-record.php
- * @param $host <p>
+ * @param string $host <p>
  * <b>host</b> may either be the IP address in
  * dotted-quad notation or the host name.
  * </p>
- * @param $type [optional] <p>
+ * @param string $type [optional] <p>
  * <b>type</b> may be any one of: A, MX, NS, SOA,
  * PTR, CNAME, AAAA, A6, SRV, NAPTR, TXT or ANY.
  * </p>
@@ -880,9 +897,10 @@ function checkdnsrr ($host, $type = null) {}
 /**
  * &Alias; <function>getmxrr</function>
  * @link https://php.net/manual/en/function.dns-get-mx.php
- * @param $hostname
- * @param $mxhosts
- * @param $weight [optional]
+ * @param string $hostname
+ * @param array &$mxhosts
+ * @param array &$weight [optional]
+ * @return bool
  */
 function dns_get_mx ($hostname, array &$mxhosts, array &$weight = null) {}
 
@@ -892,11 +910,11 @@ function dns_get_mx ($hostname, array &$mxhosts, array &$weight = null) {}
  * @param string $hostname <p>
  * The Internet host name.
  * </p>
- * @param array $mxhosts <p>
+ * @param array &$mxhosts <p>
  * A list of the MX records found is placed into the array
- * mxhosts. 
+ * mxhosts.
  * </p>
- * @param array $weight [optional] <p>
+ * @param array &$weight [optional] <p>
  * If the weight array is given, it will be filled
  * with the weight information gathered.
  * </p>
@@ -940,11 +958,11 @@ function getmxrr ($hostname, array &$mxhosts, array &$weight = null) {}
  * always return every record, the slower DNS_ALL
  * will collect all records more reliably.
  * </p>
- * @param array $authns [optional] <p>
+ * @param array &$authns [optional] <p>
  * Passed by reference and, if given, will be populated with Resource
  * Records for the Authoritative Name Servers.
  * </p>
- * @param array $addtl [optional] <p>
+ * @param array &$addtl [optional] <p>
  * Passed by reference and, if given, will be populated with any
  * Additional Records.
  * </p>
@@ -1112,4 +1130,4 @@ function getmxrr ($hostname, array &$mxhosts, array &$weight = null) {}
  * </tr>
  * </table>
  */
-function dns_get_record ($hostname, $type = DNS_ANY, array &$authns = null, array &$addtl = null, &$raw = false) {}
+function dns_get_record ($hostname, $type = DNS_ANY, array &$authns = null, array &$addtl = null, $raw = false) {}
